==> ssp-center-api-1.2.32-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/cpa/CpaDailyProfitBindingPlatformDto.java <==
package cn.com.duiba.tuia.ssp.center.api.dto.cpa;

import java.io.Serializable;
import java.util.Date;

/**
* 程序化分成利润数据表-绑定平台
*/
public class CpaDailyProfitBindingPlatformDto implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
    * 创建时间
    */
    private Date gmtCreate;

    /**
    * 更新时间
    */
    private Date gmtModified;

    /**
    * id
    */
    private Long id;

    /**
    * 绑定运营id
    */
    private Long operatorId;

    /**
    * 运营名称
    */
    private String operatorName;

    /**
    * 绑定平台id
    */
    private Long platformId;

    /**
    * 平台名称
    */
    private String platformName;

    /**
    * 产品id
    */
    private Long productId;

    /**
    * 产品名称
    */
    private String productName;

    /**
     * 备注
     */
    private String dataDesc;

    public String getDataDesc() {
        return dataDesc;
    }

    public void setDataDesc(String dataDesc) {
        this.dataDesc = dataDesc;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }

    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }

    public String getOperatorName() {
        return operatorName;
    }

    public void setPlatformId(Long platformId) {
        this.platformId = platformId;
    }

    public Long getPlatformId() {
        return platformId;
    }

    public void setPlatformName(String platformName) {
        this.platformName = platformName;
    }

    public String getPlatformName() {
        return platformName;
    }

    public void setProductId(Long productId) {
        this.productId = productId;
    }

    public Long getProductId() {
        return productId;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }

    public String getProductName() {
        return productName;
    }

}

==> ssp-center-api-1.2.46-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/cpa/CpaDailyProfitBindingPlatformDto.java <==
package cn.com.duiba.tuia.ssp.center.api.dto.cpa;

import java.io.Serializable;
import java.util.Date;

/**
* 程序化分成利润数据表-绑定平台
*/
public class CpaDailyProfitBindingPlatformDto implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
    * 创建时间
    */
    private Date gmtCreate;

    /**
    * 更新时间
    */
    private Date gmtModified;

    /**
    * id
    */
    private Long id;

    /**
    * 绑定运营id
    */
    private Long operatorId;

    /**
    * 运营名称
    */
    private String operatorName;

    /**
    * 绑定平台id
    */
    private Long platformId;

    /**
    * 平台名称
    */
    private String platformName;

    /**
    * 产品id
    */
    private Long productId;

    /**
    * 产品名称
    */
    private String productName;

    /**
     * 备注
     */
    private String dataDesc;

    private String curDate;

    public String getCurDate() {
        return curDate;
    }

    public void setCurDate(String curDate) {
        this.curDate = curDate;
    }

    public String getDataDesc() {
        return dataDesc;
    }

    public void setDataDesc(String dataDesc) {
        this.dataDesc = dataDesc;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }

    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }

    public String getOperatorName() {
        return operatorName;
    }

    public void setPlatformId(Long platformId) {
        this.platformId = platformId;
    }

    public Long getPlatformId() {
        return platformId;
    }

    public void setPlatformName(String platformName) {
        this.platformName = platformName;
    }

    public String getPlatformName() {
        return platformName;
    }

    public void setProductId(Long productId) {
        this.productId = productId;
    }

    public Long getProductId() {
        return productId;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }

    public String getProductName() {
        return productName;
    }

}
